<?php
/**
* MyPhotoPlugin.class.php
* 
* Plugin zum Bloggen
* 
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2007-2009 Jan Kulmann <jankul@zmml.uni-bremen.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

include_once("classes/BlogEntry.class.php");
include_once("classes/BlogDBM.class.php");
require_once ("lib/messaging.inc.php");
require_once('vendor/flexi/template_factory.php');

$GLOBALS['sess']->register('set_date');
$GLOBALS['sess']->register('search_datum');
$GLOBALS['sess']->register('search_txt');
$GLOBALS['sess']->register('search_cat');

class BloggingPlugin extends AbstractStudIPHomepagePlugin {

	var $user = NULL;
	var $permissions;
	var $req_user = NULL;
	var $permalink;
	var $messaging;
	var $dbm;
	var $template_path;
        var $factory;
	var $monate;
	var $set_date;
	var $search_datum;
	var $search_txt;
	var $search_cat;

	function BloggingPlugin(){
		parent::AbstractStudIPHomepagePlugin();
		$this->template_path = dirname(__FILE__) . '/templates/flexi';
                $this->factory = new Flexi_TemplateFactory($this->template_path);
		$this->setPluginIconName('images/edit_transparent.gif');
		$this->user = $this->getUser();
		$this->permissions = $this->user->getPermission();
		$this->messaging = new messaging;
		$this->dbm = new BlogDBM();
		$this->set_date = &$GLOBALS['set_date'];
		$this->search_datum = &$GLOBALS['search_datum'];
		$this->search_txt = &$GLOBALS['search_txt'];
		$this->search_cat = &$GLOBALS['search_cat'];
		if (!is_array($this->search_datum)) $this->search_datum = array();
		if (!is_array($this->search_txt)) $this->search_txt = array();
		if (!is_array($this->search_cat)) $this->search_cat = array();
	}
	
	function setPluginpath($newpath){
		parent::setPluginpath($newpath);
		$this->buildMenu();
	}

	function setRequestedUser($user) {
                parent::setRequestedUser($user);
		$u = new StudIPUser();
		$u = $this->getRequestedUser();
		$this->req_user = $u;
                $this->setStatusShowOverviewPage($this->dbm->hasPublicEntries($this->req_user->getUserId()));
		$this->permalink = $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath()."/blog.php?a=";

        }

	function getPluginname() {
                return "Blog";
        }
	
	function buildMenu(){
		$tab = new PluginNavigation();
		$tab->setDisplayname(_("Blog"));
		$subnav = new PluginNavigation();
                $subnav->setDisplayname("Neuer Eintrag");
                $subnav->setActive();
                $subnav->addLinkParam("blmodus","create_entry");
                $tab->addSubmenu($subnav);
		/*$subnav = new PluginNavigation();
                $subnav->setDisplayname("Neue Kategorie");
                $subnav->setActive();
                $subnav->addLinkParam("blmodus","new_category");
                $tab->addSubmenu($subnav);*/
		$this->setNavigation($tab); 
	}

	function createCategoryListing() {
		$template = $this->factory->open('admin_category_listing');
		$template->set_attribute('cats', $this->dbm->getAdminCategories($this->req_user->getUserId()));
		$template->set_attribute('img_uri', $this->getPluginpath().'/images');
		$template->set_attribute('ajax_uri', PluginEngine::getLink($this,array(),'ajaxdispatch'));
		$template->set_attribute('delete_cat_uri', PluginEngine::getLink($this,array('blmodus'=>'delete_cat')));
		return $template->render();
	}

	function createDateListing() {
		if (count($this->dbm->getAdminDates($this->req_user->getUserId())) == 0) return FALSE;
		$template = $this->factory->open('admin_date_listing');
		$template->set_attribute('dates', $this->dbm->getAdminDates($this->req_user->getUserId()));
		$template->set_attribute('img_uri', $this->getPluginpath().'/images');
		$template->set_attribute('uri', PluginEngine::getLink($this,array()));
		return $template->render();
	}
	

	function createInfoBox ($imgLogo) {
		$infos = array();
                array_push($infos, array ("icon" => "info.gif", "text" => _("Hier k&ouml;nnen Sie Ihren pers&ouml;nlichen Blog mit Inhalten f&uuml;llen.")));
                array_push($infos, array ("icon" => "vote-icon-visible.gif", "text" => _("Damit Ihre Beitr&auml;ge von anderen Benutzern gelesen werden k&ouml;nnen, muss die Sichtbarkeit aktiviert werden.")));
		$hilfen = array();
		array_push($hilfen, array ("icon" => "asmile.gif", "text" => _("<A HREF=\"show_smiley.php\">Liste mit allen Smilies</A>")));
		array_push($hilfen, array ("icon" => "info.gif", "text" => _("<A HREF=\"http://hilfe.studip.de/index.php/Basis.VerschiedenesSmileys?setstudiplocationid=uhb\">Hilfe zu Smilies</A>")));
		array_push($hilfen, array ("icon" => "hilfe.gif", "text" => _("<A HREF=\"http://hilfe.studip.de/index.php/Basis.VerschiedenesFormat?setstudiplocationid=uhb\">Hilfe zur Textformatierung</A>")));
                $infobox = array (array ("kategorie" => _("Information:"), "eintrag"   => $infos));
		array_push($infobox, array("kategorie"=>_("Smilies & Textformatierung:"), "eintrag"=>$hilfen));
		array_push($infobox, array("kategorie"=>_("Kategorien:"), "eintrag"=>array(array('icon'=>'txt-icon.gif','text'=>$this->createCategoryListing()))));
		$date_listing = $this->createDateListing();
		if ($date_listing)
			array_push($infobox, array("kategorie"=>_("Zeitstrahl:"), "eintrag"=>array(array('icon'=>'icon-uhr.gif','text'=>$date_listing))));
                return print_infobox ($infobox, $imgLogo, YES);
        }

	function printSingleEntry($entry_id, $ret=FALSE) {
		$e = new BlogEntry();
		$e->load($entry_id);
		include($GLOBALS['ABSOLUTE_PATH_STUDIP'].$this->getPluginpath() . '/config.inc.php');
		$this->monate = $MONATE;
		$trackbacks = $this->dbm->getTrackbackUris($e, $this->permalink);

		$template = $this->factory->open('single_blog_entry');
                $template->set_attribute('e', $e);
                $template->set_attribute('trackbacks', $trackbacks);
                $template->set_attribute('creation_date', date("d. ", $e->getMkdate()).$this->monate[date('n',$e->getMkdate())]." ".date('Y',$e->getMkdate())." @ ".date("H:i",$e->getMkdate()));
		$template->set_attribute('img_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath().'/images');
		$template->set_attribute('edit_uri', PluginEngine::getLink($this,array('open' => $entry_id),'showAdministrationPage'));
                $template->set_attribute('permalink', $this->permalink);
                $template->set_attribute('categories', $e->getCategories());
		$template->set_attribute('req_username', $this->req_user->getUsername());
		$template->set_attribute('search_uri', "about.php?username=".$this->req_user->getUsername()."&blmodus=show_search_results");
		if (!$ret)
	                echo $template->render();
		else
			return $template->render();
	}

	function printTagCloud($ret=FALSE) {
                $tags = $this->dbm->getTagCounter();
                if (count($tags) < 5) return;
                $template = $this->factory->open('show_tag_cloud');
                $template->set_attribute('tags', $tags);
                $template->set_attribute('css_uri', $this->getPluginURL().'/css');
                $template->set_attribute('search_uri', "about.php?username=".$this->req_user->getUsername()."&blmodus=show_search_results");
		if (!$ret)
                        echo $template->render();
                else
                        return $template->render();
        }



	function actionShowAdministrationPage() {
		$GLOBALS['perm']->check('autor');

		$this->getStyle();

		$db = new DB_Seminar();
                $db2 = new DB_Seminar();
                $msg = "";

		if ($this->req_user->getUserId() == $this->user->getUserId() || $GLOBALS['perm']->have_perm("root")) {

			if (trim($_REQUEST['set_date']) != "" && is_numeric(trim($_REQUEST['set_date']))) $this->set_date = trim($_REQUEST['set_date']);

                        echo "<TABLE BORDER=\"0\" WIDTH=\"100%\"><TR><TD VALIGN=\"TOP\">\n";

			$open = trim($_REQUEST['open']);
                        $modus = trim($_REQUEST['blmodus']);
                        $modus2 = trim($_REQUEST['blmodus2']);

			if ($modus == "new_category") {
				$template = $this->factory->open('create_new_category');
				$template->set_attribute('uri', PluginEngine::getLink($this,array()));
				echo $template->render();
			}
			if ($modus == "create_new_category") {
				$titel = trim($_REQUEST['title']);
				if ($titel) {
					$this->dbm->createCategory(trim($titel), $GLOBALS['auth']->auth['uid']);
					$msg = "msg"._("Die Kategorie wurde angelegt!");
				}
			}
			if ($modus == "create_entry") {
				$id =  md5(uniqid(time()));
				$titel = _("Neuer Eintrag");
				$desc = _("Neuer Eintrag");
				$e = new BlogEntry();
				$e->setTitel($titel);
				$e->setDescription($desc);
				$e->setUserId($this->user->getUserId());
				$e->save();
				$open = $e->getEntryId();
				$msg = "msg"._("Eintrag angelegt.");
				$this->set_date = FALSE;
			}
			if ($modus == "save_entry" || $modus == "preview") {
                                $id = trim($_REQUEST['entry_id']);
				$e = new BlogEntry();
				$e->load($id);
				if ($modus2 == "delete_tag") {
                                        if ($e->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
                                                $e->removeTag(trim($_REQUEST['tag']));
						$msg = "msg"._("Tag gel&ouml;scht!");
                                        }
                                }

                                $titel = trim($_REQUEST['titel']);
                                $description = trim($_REQUEST['description']);
                                $visible = (trim($_REQUEST['visible']) ? 1 : 0);
				$cat_id = trim($_REQUEST['category_id']);
                                if (strlen(trim($titel)) > 0) {
					$e->setTitel($titel);
	                                $e->setDescription($description);
					$e->setVisible($visible);
					$e->save();
					$e->setTags(trim($_REQUEST['tags']));
					if ($cat_id) $e->addCategory($cat_id);
                                        $msg = "msg"._("Eintrag gespeichert!");
                                }
                                $open = $id;
                        }
			if ($modus == "delete_entry") {
                                $id = trim($_REQUEST['entry_id']);
				$e = new BlogEntry();
				$e->load($id);
				$template = $this->factory->open('delete_entry');
		                $template->set_attribute('delete_uri', PluginEngine::getLink($this,array("blmodus"=>"delete_entry_really","entry_id"=>$id)));
        	        	$template->set_attribute('cancel_uri', PluginEngine::getLink($this,array("open"=>$id)));
        	        	$template->set_attribute('commentCount', $e->getCommentCount());
        	        	echo $template->render();
                        }
			if ($modus == "delete_cat") {
				$id = trim($_REQUEST['cat_id']);
				$c = $this->dbm->getCategory($id);
                                if ($c) {
					$this->dbm->deleteCategory($id);
				}
			}
                        if ($modus == "delete_entry_really") {
                                $id = trim($_REQUEST['entry_id']);
				$e = new BlogEntry();
                                $e->load($id);
				$e->delete();
                                $msg = "msg"._("Eintrag wurde gel&ouml;scht!");
				if ($GLOBALS['auth']->auth["uid"] != $this->req_user->getUserId()) {
					$message = "Ein Blog-Eintrag wurde von der Administration geloescht!\n\n";
                                        $this->messaging->insert_message($message, get_username($this->req_user->getUserId()), "____%system%____", FALSE, FALSE, 1, FALSE, _("Blog-Eintrag geloescht"));
				}
				$this->set_date = FALSE;
                        }
			if ($modus == "delete_comment") {
				$entry_id = trim($_REQUEST['open']);
				$comment_id = trim($_REQUEST['comment_id']);
				$e = new BlogEntry();
				$e->load($entry_id);
				// Ist es wirklich der eigene Blogeintrag, zu dem der Kommentar geloescht werden soll?
				if ($e->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
					$e->deleteComment($comment_id);
					$msg = "msg"._("Kommentar wurde gel&ouml;scht!");
					$modus = "view_comments";
					if ($GLOBALS['auth']->auth["uid"] != $this->req_user->getUserId()) {
						$message = "Ein Blog-Kommentar wurde von der Administration geloescht!\n\n";
                                        	$this->messaging->insert_message($message, get_username($this->req_user->getUserId()), "____%system%____", FALSE, FALSE, 1, FALSE, _("Blog-Kommentar geloescht"));
					}
				}
			}
			if ($modus == "add_category") {
				$id = trim($_REQUEST['entry_id']);
				$cat_id = trim($_REQUEST['category_id']);
				if ($id && $cat_id) {
					$e = new BlogEntry();
					$e->load($id);
					$c = $this->dbm->getCategory($cat_id);
					if ($e->getUserId() == $GLOBALS['auth']->auth['uid'] && $c['user_id'] == $GLOBALS['auth']->auth['uid']) {
						$e->addCategory($cat_id);
					}
				}
				$open = $id;
			}

			if ($msg) {
                                echo "<TABLE BORDER=\"0\">\n";
                                parse_msg($msg);
                                echo "</TABLE>\n";
                        }

			/*$template = $this->factory->open('create_new_entry');
                        $template->set_attribute('uri', PluginEngine::getLink($this,array()));
			echo $template->render();*/
			if (!$this->set_date) {
				$dates = $this->dbm->getAdminDates($this->req_user->getUserId());
				if (count($dates) > 0) 
					$this->set_date = $dates[0]['datum_ts'];
			}
			if ($this->set_date)
				echo "<TABLE CELLSPACING=0 STYLE=\"width:100%;\"><TR><TD CLASS=\"topic\" STYLE=\"height:22px;\"><SPAN CLASS=\"date\" STYLE=\"border-bottom:0px; color:white;\">".date('Y-m',$this->set_date)."</SPAN></TD><TR></TABLE>";

			$entries = $this->dbm->getAllEntries($this->req_user->getUserId(), FALSE, ($this->set_date ? $this->set_date : FALSE));
			

			//echo $this->createCategoryListing();
			if (count($entries) == 0) {
				echo "<DIV STYLE=\"text-align:center;\"><SPAN CLASS=\"title\">Sie haben noch keine Eintr&auml;ge verfasst, f&uuml;llen Sie Ihren Blog mit Leben!</SPAN></DIV>";
			} else {
?>
				<script type="text/javascript" language="javascript">
				function changeVisibility(id) {
					if (id != "") {
						new Ajax.Request('<?=PluginEngine::getLink($this,array('ajax_cmd'=>'change_visibility'),'ajaxdispatch')?>', {
							parameters: 'entry_id='+id,
				                        method: 'post',
				                        onSuccess: function(t) { location.reload(); },
				                        onFailure: function(t) {alert('Error ' + t.status + ' -- ' + t.statusText); },
				                        on404: function(t) {alert('Error 404: location "' + t.statusText + '" was not found.'); }
				                });
					}
				}
				</script>
<?
			}
			foreach ($entries as $e) {
				$link = PluginEngine::getLink($this,array());
				$icon = "<IMG SRC=\"".$GLOBALS['ASSETS_URL']."images/news2.gif\" ALT=\"Blogentry\">";
				$tmp_titel=htmlReady(mila($e->getTitel()));
				$zusatz = "<A HREF=\"javascript:changeVisibility('".$e->getEntryId()."');\">".($e->getVisible() == 1 ? "<IMG SRC=\"".$this->getPluginpath()."/images/visible.gif\" ALT=\""._("sichtbar")."\" TITLE=\""._("sichtbar")."\">" : "<IMG SRC=\"".$this->getPluginpath()."/images/invisible.gif\" ALT=\""._("unsichtbar")."\" TITLE=\""._("unsichtbar")."\">")."</A>&nbsp;".date("d.m.Y H:i",$e->getMkdate());
				$titel = "<A HREF=\"".$link."&open=".($open==$e->getEntryId()?"":$e->getEntryId()."#anker")."\"><FONT SIZE=\"-1\">".$tmp_titel."</FONT></A>";
				echo "             <TABLE BORDER=\"0\" WIDTH=\"100%\" CELLPADDING=\"0\" CELLSPACING=\"0\">\n";
                                echo "               <TR>\n";
                                printhead ("100%", 0, $link, ($open==$e->getEntryId()?"open":"close"), FALSE, $icon, $titel, $zusatz, time());
                                echo "               </TR>\n";
                                echo "             </TABLE>\n";
                                if ($open == $e->getEntryId()) {
					$template = $this->factory->open('edit_entry');
			                $template->set_attribute('e', $e);
			                $template->set_attribute('css_uri', $this->getPluginURL().'/css');
					$template->set_attribute('delete_tag_uri', PluginEngine::getLink($this,array("blmodus"=>"save_entry","blmodus2"=>"delete_tag","entry_id"=>$e->getEntryId())));
					$template->set_attribute('delete_cat_uri', PluginEngine::getLink($this,array("blmodus"=>"save_entry","blmodus2"=>"delete_cat","entry_id"=>$e->getEntryId())));
			                $template->set_attribute('img_uri', $GLOBALS['ASSETS_URL']."/images/");
					$template->set_attribute('ajax_uri', PluginEngine::getLink($this,array('ajax_cmd' => 'tag_completer'),'ajaxdispatch'));
			                $template->set_attribute('save_uri', PluginEngine::getLink($this,array()));
			                $template->set_attribute('permalink', $this->permalink);
			                $template->set_attribute('all_categories', $this->dbm->getAdminCategories($e->getUserId()));
			                $template->set_attribute('used_categories', $e->getCategories());
			                echo $template->render();

					if ($modus == "preview") {
						$this->printSingleEntry($e->getEntryId());
					}
				
					$template = $this->factory->open('admin_comments');
                                        $template->set_attribute('comments', $e->getComments());
                                        $template->set_attribute('modus', $modus);
                                        $template->set_attribute('comments_open_uri', PluginEngine::getLink($this,array("open"=>$e->getEntryId())).($modus != "view_comments" ? "&blmodus=view_comments" : "")."#anker_comments");
                                        $template->set_attribute('delete_comment_uri', PluginEngine::getLink($this,array("open"=>$e->getEntryId()))."&blmodus=delete_comment");
					echo $template->render();
				}
			}

			echo "</TD><TD>\n";
                        echo "<TD WIDTH=\"20%\" VALIGN=\"TOP\">\n";
                        echo $this->createInfoBox("sms3.jpg");

                        echo "</TD></TR></TABLE>\n";

		} else
			echo _("Zugriff verweigert!");
	}

	function actionShow() {
		$GLOBALS['perm']->check('autor');
		$this->actionShowAdministrationPage();
	}

	function getStyle() {
		echo "<LINK REL=\"stylesheet\" HREF=\"".$this->getPluginURL()."/css/style-blog.css\" TYPE=\"text/css\" />\n";
	}

	function resetSearch() {
		$this->search_txt[$this->req_user->getUserId()] = FALSE;
                $this->search_datum[$this->req_user->getUserId()] = FALSE;
                $this->search_cat[$this->req_user->getUserId()] = FALSE;
	}

	function showOverview() {
		$GLOBALS['perm']->check('autor');
		$this->getStyle();

		$modus = $_REQUEST['blmodus'];

		$this->search_txt[$this->req_user->getUserId()] = ($_REQUEST['search_text'] && $_REQUEST['search_text'] != "-1" ? trim($_REQUEST['search_text']) : "");
		$this->search_datum[$this->req_user->getUserId()] = ($_REQUEST['date'] && $_REQUEST['date'] != "-1" ? trim($_REQUEST['date']) : "");
		$this->search_cat[$this->req_user->getUserId()] = ($_REQUEST['cat'] && $_REQUEST['cat'] != "-1" ? trim($_REQUEST['cat']) : "");

		if ($modus == "search_reset") {
			/*$this->search_txt[$this->req_user->getUserId()] = FALSE;
			$this->search_datum[$this->req_user->getUserId()] = FALSE;
			$this->search_cat[$this->req_user->getUserId()] = FALSE;*/
			$this->resetSearch();
			unset($modus);
		}
		if ($modus == "send_report_really") {
                        $username = trim($_REQUEST['username']);
                        $report = trim($_REQUEST['report']);
                        if (strlen($username) > 0 && $report != "") {
				$entry_id = $this->dbm->getEntryIdFromPermid($_REQUEST['permid']);
				$e = new BlogEntry();
	                        $e->load($entry_id);
                                $subject = _("Meldung eines Blog-Eintrages");
                                $message = sprintf(_("Ein Blogeintrag von %s (%s) wurde von %s (%s) beanstandet:\n\n"),htmlReady(get_fullname($this->req_user->getUserId())), get_username($this->req_user->getUserId()), htmlReady(get_fullname($GLOBALS['auth']->auth['uid'])), get_username($GLOBALS['auth']->auth['uid']));
                                $message .= "Begrndung: ".($report ? htmlReady($report) : "Keine Begrndung angegeben!")."\n\n";
                                $message .= "Titel: ".htmlReady($e->getTitel())." (".date("d.m.Y H:i",$e->getMkdate())." / ".date("d.m.Y H:i",$e->getChdate()).")\n\n";
                                $message .= "Inhalt:\n".$e->getDescription();
                                $header .= "From: " . get_fullname($GLOBALS['auth']->auth['uid'])." <".$this->dbm->get_email($GLOBALS['auth']->auth['uid']).">\r\n";
                                $header .= "Reply-To: " . get_fullname($GLOBALS['auth']->auth['uid']) ." <".$this->dbm->get_email($GLOBALS['auth']->auth['uid']).">\r\n";
                                @mail($GLOBALS['UNI_CONTACT'], $subject, $message, $header);
                        }
			unset($modus);
                }
		if ($modus == "add_comment") {
			$entry_id = $this->dbm->getEntryIdFromPermid($_REQUEST['permid']);
			$e = new BlogEntry();
			$e->load($entry_id);
			if ($e->addComment($_REQUEST['comment'])) {
				if ($GLOBALS['auth']->auth["uid"] != $this->req_user->getUserId()) {
					$message = _("Du hast einen neuen Kommentar in deinem Blog!")."\n\n";
					$message .= $this->permalink.$_REQUEST['permanent_id'];
					$messaging=new messaging;
					$messaging->insert_message($message, $this->req_user->getUsername(), $GLOBALS['auth']->auth["uid"], FALSE, FALSE, 1, FALSE, _("Neuer Blog-Kommentar"));
				}
			}
			unset($modus);
		}
		if ($this->search_txt || $this->search_cat || $this->search_datum) {
			$modus = "show_search_results";
		}
		if ($modus == "show_search_results") {
			/*$txt = trim($_REQUEST['search_text']);
			$cat_id = ($_REQUEST['cat'] ? $_REQUEST['cat'] : FALSE);
			$datum = ($_REQUEST['date'] ? $_REQUEST['date'] : FALSE);*/
			if ($this->search_txt[$this->req_user->getUserId()] || $this->search_cat[$this->req_user->getUserId()] || $this->search_datum[$this->req_user->getUserId()]) {
				$only_user = ($_REQUEST['only_this_user'] == "yes" ? $this->req_user->getUserId() : FALSE);
				$entries = $this->dbm->searchForText($this->search_txt[$this->req_user->getUserId()], $only_user, $this->search_cat[$this->req_user->getUserId()], $this->search_datum[$this->req_user->getUserId()], $this->req_user->getUserId());
				$active_blogger = $this->dbm->getActivePublicBlogger(10);
				$categories = $this->dbm->getPublicCategories($this->req_user->getUserId());
				$tmp_entries = array();
				foreach ($entries as $e)
					array_push($tmp_entries, $this->printSingleEntry($e->getEntryId(), TRUE));
				$template = $this->factory->open('public_search_results_view');
				$template->set_attribute('fullname', htmlReady(get_fullname($this->req_user->getUserId())));
				$template->set_attribute('cat_search', $this->search_cat[$this->req_user->getUserId()]);
				$template->set_attribute('categories', $categories);
				$template->set_attribute('req_username', $this->req_user->getUsername());
				$template->set_attribute('entries', $tmp_entries);
				$template->set_attribute('public_dates', $this->dbm->getPublicDates($this->req_user->getUserId()));
				$template->set_attribute('active_blogger', $active_blogger);
				$template->set_attribute('tag_cloud', $this->printTagCloud(TRUE));
				$template->set_attribute('css_uri', $this->getPluginURL().'/css');
				$template->set_attribute('ajax_uri', PluginEngine::getLink($this,array('ajax_cmd' => 'tag_completer'),'ajaxdispatch'));
				echo $template->render();
			} else {
				unset($modus);
			}
		}

		if (!$modus) {
			/*$public_dates = $this->dbm->getPublicDates($this->req_user->getUserId());
			if (count($public_dates) > 0)
				$entries = $this->dbm->searchForText('', FALSE, FALSE, $public_dates[0]['datum_ts']);
			else
				$entries = $this->dbm->getPublicEntries($this->req_user->getUserId());*/
			$latest_entries = $this->dbm->getPublicEntries($this->req_user->getUserId(), 10);
			$active_blogger = $this->dbm->getActivePublicBlogger(10);
			$categories = $this->dbm->getPublicCategories($this->req_user->getUserId());
	
			$tmp_entries = array();
			foreach ($latest_entries as $e)
				array_push($tmp_entries, $this->printSingleEntry($e->getEntryId(), TRUE));

			$template = $this->factory->open('public_main_view');
			$template->set_attribute('fullname', htmlReady(get_fullname($this->req_user->getUserId())));
			$template->set_attribute('entries', $tmp_entries);
			$template->set_attribute('categories', $categories);
			$template->set_attribute('latest_entries', $latest_entries);
			$template->set_attribute('active_blogger', $active_blogger);
			$template->set_attribute('public_dates', $this->dbm->getPublicDates($this->req_user->getUserId()));
			$template->set_attribute('req_username', $this->req_user->getUsername());
			$template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->getPluginpath());
			$template->set_attribute('tag_cloud', $this->printTagCloud(TRUE));
			$template->set_attribute('css_uri', $this->getPluginURL().'/css');
			$template->set_attribute('ajax_uri', PluginEngine::getLink($this,array('ajax_cmd' => 'tag_completer'),'ajaxdispatch'));
			echo $template->render();
		}
	}

	function actionAjaxDispatch(){
		ob_end_clean();
		if (!array_key_exists('ajax_cmd', $_REQUEST)) die;
		switch($_REQUEST['ajax_cmd']) {
			case 'tag_completer':
		                $val = escapeshellcmd(basename(trim($_REQUEST['value'])));
		                if ($val == "") return;
		                echo BlogDBM::searchForTags($val);
		                break;
			case 'update_cat_title':
				$id = escapeshellcmd(basename(trim($_REQUEST['catid'])));
				$title = escapeshellcmd(basename(trim($_REQUEST['title'])));
				$c = $this->dbm->getCategory($id);
				if ($c) {
					if ($c['user_id'] == $GLOBALS['auth']->auth['uid']) {
						$this->dbm->updateCategory($id, $title);
					}
					echo stripslashes(stripslashes($title));
				}
				break;
			case 'change_visibility':
				$id = escapeshellcmd(basename(trim($_REQUEST['entry_id'])));
				if ($id) {
					$e = new BlogEntry();
					$e->load($id);
					if ($e->getUserId() == $GLOBALS['auth']->auth['uid']) {
						if ($e->getVisible() == 1) $e->setVisible(0);
						else $e->setVisible(1);
						$e->save();
						echo "success";
					} else echo "error";
				}
				break;
			default: ;
		}
		die();
	}

}

?>
