<?php

/**
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2007-2009 Jan Kulmann <jankul@zmml.uni-bremen.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

require_once 'BlogDBM.class.php';
require_once 'BlogEntry.class.php';
require_once('vendor/flexi/template_factory.php');

class RSSProducer {

	var $factory;
        var $template_path;
        var $dbm;
        var $rss_path;
	var $category_id;
	
	function RSSProducer($dbm, $rss_path) {
		$this->rss_path = $rss_path;
                $this->template_path = dirname(__FILE__) . '/../templates/flexi/rss';
                $this->factory = new Flexi_TemplateFactory($this->template_path);
                $this->dbm = &$dbm;
		$this->category_id = FALSE;
	}

	function setCategoryId($s) {
		$this->category_id = $s;
	}
	
	function create_rss_stream($user_id) {
		$RssTimeFmt = '%Y-%m-%dT%H:%MZ';
                $last_changed = time();

		if (!$this->category_id)
	                $res = $this->dbm->getPublicEntries($user_id);
		else
			$res = $this->dbm->searchForText('',FALSE,$this->category_id);

		$email = preg_replace(array("/@/","/\./"),array(" at ", " dot "),$this->dbm->get_email($user_id));

                $studip_url = $GLOBALS['ABSOLUTE_URI_STUDIP'];
                $RssChannelDesc = ' (Stud.IP - ' . $GLOBALS['UNI_NAME_CLEAN'] . '). ';
		$RssChannelDesc .= "Hinweis: Der Betreiber dieses Dienstes ist nicht fr den dargestellten Inhalt verantwortlich!";
                $title = "Persnlicher Blog von ".htmlReady(get_fullname($user_id))." [$email]";

                $items = array();
                foreach ($res as $a) {
                        $tags = $a->getTags();
                        $beschreibung = formatready($a->getDescription(),1,1);
                        if (count($tags) > 0) {
                                $beschreibung .= "<BR><BR><SPAN STYLE=\"font-size:0.7em;\">Tags: | ";
                                foreach ($tags as $tt)
                                        $beschreibung .= $tt." | ";
                                $beschreibung .= "</SPAN>";
                        }
                        $template = $this->factory->open('rss_item');
                        $template->set_attribute('titel', utf8_encode($a->getTitel()));
                        $template->set_attribute('rss_uri', $this->rss_path.'?a='.$a->getPermanentId());
                        $template->set_attribute('beschreibung', utf8_encode($beschreibung));
                        $template->set_attribute('fullname', utf8_encode(htmlready(get_fullname($a->getUserId()))));
                        $template->set_attribute('mkdate', gmstrftime($RssTimeFmt,$a->getMkdate()));
                        $template->set_attribute('pubdate', date("r",$a->getMkdate()));
                        array_push($items, $template->render());
                }

                $template = $this->factory->open('rss_body');
                $template->set_attribute('titel', utf8_encode($title));
                $template->set_attribute('studip_url', $studip_url);
                $template->set_attribute('xml', "<?xml version=\"1.0\"?>");
                $template->set_attribute('rss', "<rss version=\"2.0\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\">");
                $template->set_attribute('RssChannelDesc', utf8_encode($RssChannelDesc));
                $template->set_attribute('last_changed', date("r",$last_changed));
                $template->set_attribute('generator', utf8_encode('Stud.IP - ' . htmlspecialchars($GLOBALS['SOFTWARE_VERSION'])));
                $template->set_attribute('items', $items);

                header("Content-type: text/xml; charset=utf-8");
                echo $template->render();

                return true;
	}

}

?>
